# Functions for manipulating the grid environment
#
# gridpath_prepend - prepend a value to a path-like environmnet variable
#                                     - puts a ':' to the end end the beginning of the variable
#                                     - removes the value from the string and removes duplicate '::'
#                                     - prepend the value to the beginning of the variable
#                                     - removes duplicate '::' and removes ':' from the beginning and the end variable
#                                     - MANPATH has to be treated specially since, :: has a meaning -> don't get removed
#                                     - export the variable, or echos the csh syntax
#
# gridpath_append - the same as prepend but it appends the value to the end of the variable
# gridenv_delete  - delete a value from an environment variable. if the value becomes null string then it unsets the environment variable
# gridemv_set     - sets an environment variable
# gridenv_setind  - sets an environment variable if it is not already defined


function gridpath_prepend() {
		myvar="$1"
		myvalue="$2"
		myfieldsep=":"

		eval mytmp=\""\${${myvar}}"\"
		mytmp="$myfieldsep$mytmp$myfieldsep"
		mytmp="${mytmp//$myfieldsep$myvalue$myfieldsep/$myfieldsep}"
		mytmp="$myvalue$myfieldsep$mytmp"
		mytmp="${mytmp//$myfieldsep$myfieldsep$myfieldsep/}"
 		mytmp="${mytmp//$myfieldsep$myfieldsep/$myfieldsep}"
		mytmp="${mytmp%$myfieldsep}"
		mytmp="${mytmp#$myfieldsep}"
                if [ "x$myvar" = "xMANPATH" ] ; then
                  mytmp="${mytmp}::"
                fi
                if [ "x$ISCSHELL" = "xyes" ]; then
                  echo "setenv $myvar \"$mytmp\"" 
                fi
		  eval export ${myvar}=\""$mytmp"\"
} 

function gridpath_append() {
		myvar="$1"
		myvalue="$2"
		myfieldsep=":"

		eval mytmp=\""\${${myvar}}"\"
		mytmp="$myfieldsep$mytmp$myfieldsep"
		mytmp="${mytmp//$myfieldsep$myvalue$myfieldsep/$myfieldsep}"
		mytmp="$mytmp$myfieldsep$myvalue"
		mytmp="${mytmp//$myfieldsep$myfieldsep$myfieldsep/}"
		mytmp="${mytmp//$myfieldsep$myfieldsep/$myfieldsep}"
		mytmp="${mytmp%$myfieldsep}"
		mytmp="${mytmp#$myfieldsep}"
                if [ "x$myvar" = "xMANPATH" ] ; then
                  mytmp="${mytmp}::"
                fi
                if [ "x$ISCSHELL" = "xyes" ]; then
                  echo "setenv $myvar \"$mytmp\"" 
                fi
  		  eval export ${myvar}=\""$mytmp"\"
} 

function gridenv_delete() {
		myvar="$1"
		myvalue="$2"
		myfieldsep=":"

                eval mytmp=\""\${${myvar}}"\"
                mytmp="$myfieldsep$mytmp$myfieldsep"
                mytmp="${mytmp//$myfieldsep$myvalue$myfieldsep/$myfieldsep}"
                mytmp="${mytmp//$myfieldsep$myfieldsep$myfieldsep/}"
                mytmp="${mytmp//$myfieldsep$myfieldsep/}"
                mytmp="${mytmp%$myfieldsep}"
                mytmp="${mytmp#$myfieldsep}"

                if [ "x$ISCSHELL" = "xyes" ]; then
                  echo "setenv $myvar \"$mytmp\"" 
                fi
                  eval export ${myvar}=\""$mytmp\""

}

function gridenv_set() {
                myvar="$1"
                myvalue="$2"
                myfieldsep=":"

                if [ "x$ISCSHELL" = "xyes" ]; then
                  echo "setenv $myvar \"$myvalue\"" 
                fi
                  eval export ${myvar}="\"${myvalue}\""
}

function gridenv_setind() {
               myvar="$1"
               myvalue="$2"
               if [ "x$ISCSHELL" = "xyes" ]; then
	          echo 'if ( ${?'$myvar'} == 0 ) setenv '$myvar \'"$myvalue"\'
               fi
               eval export $myvar=\${$myvar:-\$myvalue}
}
